
clc; clear all;close all
dirstring= '..\MatlabScriptData';
sbp = SBPDproject(dirstring);
SBPDinfo(sbp);
%%
% KEEP THE ORIGINAL PROJECT UNCHANGED
sbpopt = sbp;
% set working model and method here
workingmodel='M_LAGB_bifurcation_used'
workingmethod='DEmatSB'  % simplexSB, isresSB, pswarmSB, fSSmSB, SSmSB

sbpStruct=SBPDstruct(sbp);
for k=1: length(sbpStruct.models)
    sb=SBstruct(sbpStruct.models{k});
    if strcmp(workingmodel, sb.name)
        modelindex=k;
        break
    end
end
if isempty(modelindex)
    error('model name does not exist')
end

%%
% SBPDcomparemeasurements(sbp, modelindex);
%% SELECT PARAMETERS/STATES TO ESTIMATE AND CORRESPONDING BOUNDS
% op.lowbounds=0.1; 
% op.highbounds=10;
% getparamictextSBPD(sbp,modelindex,op);
% after paste, there is something to do, such as deleting G since it is not fitted

% Global parameters
% Names          Lower bounds  Upper bounds
paramdata = {
'm'        0.1         5
'tao'      1e-8        1e-3
};
% Local (experiment dependend) parameters
% Names          Lower bounds  Upper bounds
paramdatalocal = {
};
% nonlocal parameters
% name                 lowbound   highbound   experiment index        

% Initial conditions (always experiment dependend)
% Names          Lower bounds  Upper bounds
icdata = {
};
% nonlocal initial conditions 
% name                 lowbound        highbound     experiment index        

%% DEFINE THE ESTIMATION INFORMATION (STRUCTURE)
estimation = [];
% Mehtod, Model and experiment settings
estimation.optimization.method = workingmethod;
estimation.modelindex = modelindex;

estimation.optimization.options.I_itermax = 1e9;
estimation.optimization.options.F_weight = 0.9; % 0.8
estimation.optimization.options.F_CR = 0.9;     % 0.9
estimation.optimization.options.I_strategy = 1; % 3 cost 1639
estimation.optimization.options.I_refresh = 20;
estimation.optimization.options.F_VTR = 0.001;
estimation.optimization.options.F_thresh = 0.015;


estimation.integrator.options.method = 'stiff';
estimation.integrator.options.abstol = 1e-006;
estimation.integrator.options.reltol = 1e-006;
estimation.integrator.options.minstep = 0;
estimation.integrator.options.maxstep = Inf;
estimation.integrator.options.maxnumsteps = 10000;
estimation.integrator.options.maxnonlineariter = 3; % default 3
estimation.integrator.options.maxconvfails = 10; % default 10
estimation.integrator.options.maxerrtestfails = 50; % default 50
% Flags
estimation.displayFlag = 3; % 0, none; 1, final; 2, show iterations and final message; 3, 2+othermessages
estimation.scalingFlag = 1; % 0, no scale; 1, scale by max(abs(value)); 2, scale by mean values; 3, scale by min/max bounds
estimation.timescalingFlag = 0; % do not apply time-scaling
estimation.initialconditionsFlag = 0; % 0, from model or experiment description; 1, from first timepoint in measurements
% Always needed (do not change ... unless you know what you do)
estimation.parameters = paramdata;
estimation.parameterslocal = paramdatalocal;
estimation.initialconditions = icdata;

% Run estimation
output = SBPDparameterestimation(sbpopt,estimation)
% Get optimized project
sbpopt = output.projectopt;
%% COMPARE OPTIMIZED PROJECT WITH MEASUREMENTS
SBPDcomparemeasurements(sbpopt,modelindex);
sbm=SBPDgetmodel(sbpopt)
sbe=SBPDgetexperiment(sbpopt)
SBsimulate(SBmergemodexp(sbm{modelindex},sbe{1}),'ode15s',30*365)
% % SBPDsaveproject(sbpopt,'DualBufferModel002f');
% % SBPDexportproject(sbpopt,'DualBufferModel002f')
%%
load deopt_my_used.mat

idx=find(Fval< 0.015);
FM_ui=FM_ui(idx,:);
Fval= Fval(idx);
m_array = FM_ui(:,1);
tao_array = FM_ui(:,2);

%% history 
load glu_homaS_from_tabak.mat
load initial_condition.mat
time_day_long = [ time_day',4745+365: 365: 4745+30*365]';
time_year= time_day/365-13;
time_year_long= time_day_long/365-13;

y0=[G_incidence I_incidence IL_incidence RA_incidence B_incidence]';
k1= 947302.2872        ;
k2= 31233645.51        ;
k3= 26551.07864        ;
k4= 0.04720128697      ;
k5= 3745.722947        ;
k6= 1048112296         ;

y=zeros(length(time_year),length(Fval));
for i=1:length(Fval)
    %     pm= min(m_array)  + rand*(max(m_array)-min(m_array));
    %     ptao= min(tao_array) + rand*(max(tao_array)-min(tao_array));
    
    pm = m_array(i);
    ptao = tao_array(i);
    pk1 = k1;
    pk2 = k2;
    pk3 = k3;
    pk4 = k4;
    pk5 = k5;
    pk6 = k6;
    [~, y_incidnece] = ode15s(@(t,y) myode_all_para_perturb(t,y, time_day, homa_s_incidence, pm,ptao,pk1,pk2,pk3,pk4,pk5,pk6 ), time_day_long, y0);
    g(:,i)= y_incidnece(:,1);
    l(:,i)= y_incidnece(:,3);
    a(:,i)= y_incidnece(:,4);
    b(:,i)= y_incidnece(:,5);
end 

y0=[G_nonincidence I_nonincidence IL_nonincidence RA_nonincidence B_nonincidence]';
y_nonincidence=zeros(length(time_year),length(Fval));
for i=1:length(Fval)
    %     pm= min(m_array)  + rand*(max(m_array)-min(m_array));
    %     ptao= min(tao_array) + rand*(max(tao_array)-min(tao_array));
    
    pm = m_array(i);
    ptao = tao_array(i);
    pk1 = k1;
    pk2 = k2;
    pk3 = k3;
    pk4 = k4;
    pk5 = k5;
    pk6 = k6;
    [~, y_nonincidnece] = ode15s(@(t,y) myode_all_para_perturb(t,y, time_day, homa_s_nonincidence, pm,ptao,pk1,pk2,pk3,pk4,pk5,pk6 ), time_day_long, y0);
    g_non(:,i)= y_nonincidnece(:,1);
    
end 


%%

figure;
subplot(1,2,2)
plot(m_array,tao_array,'.')
xlabel('m')
ylabel('{\tau}')

tt= [time_year', fliplr(time_year')];
y1= min(g(1:length(time_year),:),[],2);
y2= max(g(1:length(time_year),:),[],2)
yy= [y1', fliplr(y2')];
subplot(1,2,1)
fill(tt,yy,'g')
hold on

ynon1= min(g_non(1:length(time_year),:),[],2);
ynon2= max(g_non(1:length(time_year),:),[],2)
yynon= [ynon1', fliplr(ynon2')];
subplot(1,2,1)
fill(tt,yynon,'g')

hold on
plot(time_year,glu_incidence,'k')
plot(time_year,glu_nonincidence,'r')
xlabel('Time (year)')
ylabel('Glucose (mM)')
%%
figure
subplot(1,2,1)
plot(time_year_long,g)
xlabel('Time (year)')
ylabel('Glucose (mM)')
subplot(1,2,2)
plot(time_year_long,b)
xlabel('Time (year)')
ylable('{\beta} cell mass (mg)')

%%
y1= min(l(1:length(time_year),:),[],2);
y2= max(l(1:length(time_year),:),[],2);
yy= [y1', fliplr(y2')];
subplot(2,2,2)
fill(tt,yy,'g')

y1= min(a(1:length(time_year),:),[],2);
y2= max(a(1:length(time_year),:),[],2)
yy= [y1', fliplr(y2')];
subplot(2,2,3)
fill(tt,yy,'g')

y1= min(b(1:length(time_year),:),[],2);
y2= max(b(1:length(time_year),:),[],2)
yy= [y1', fliplr(y2')];
subplot(2,2,4)
fill(tt,yy,'g')
