clear all
clc

%% data collection
tissue_blood_ratio= 20; % less than 100, similar as TNF-alpha
il1Ra_il1_ratio=500; % Maedler 2004 PNAS

il1Ra_culture= [ 113.8889  130.5556  206.9444  141.6667  122.2222  118.0556 ]'; % pg/ml Maedler 2006 Diabetes Fig. 2E
il1  = [il1Ra_culture(1)/500   10        20         200        1000     2000]'; % pg/ml Maedler 2006 Diabetes Fig. 2E

il1Ra_blood_heathy=300; % pg/ml Carstensen 2010 Diabetes Fig. 1
il1_tissue_healthy= il1Ra_blood_heathy * tissue_blood_ratio / il1Ra_il1_ratio;  
il1_tissue_after_switch= il1_tissue_healthy * 55.77; % Boeni-Schnetzler 2008 J Clin Endocrinol Metab
glu_patients=[367 294 266 181 162 195 267 190 278 ]; % corresponding to il1_after_switch
% data from supplementary information of Boeni-Schnetzler 2008 J Clin Endocrinol Metab
% availble from http://jcem.endojournals.org/content/suppl/2008/07/31/jc.2008-0396.DC1/Supplemental_tables.pdf
glu_mM_patinets=mean(glu_patients)/100*5.5;

fold_RNA_il1_auto=[  1.0000  1.0000    1.0000    3.7838    9.0541]'; % Boeni-Schnetzler 2008 J Clin Endocrinol Metab Fig. 4B
il1_il1_auto=[       il1(1)    2        20         200      1000 ]'; % Boeni-Schnetzler 2008 J Clin Endocrinol Metab Fig. 4B
   
fold_prolif=[ 1.0000    1.3702    2.0035    1.3702    1.2664    0.6747    0.6644]'; % Maedler 2006 Diabetes Fig. 1B
fold_apopto=[ 1.0000    0.5258    0.9433    1.5464    1.3454    2.2887    3.6186]'; % Maedler 2006 Diabetes Fig. 1C
il1_pro_apo=[  il1(1)    10        20         200       1000       2000     5000]'; % pg/ml Maedler 2006 Diabetes Fig. 1B C

fold_gsis_basal=[ 3.39   4.62   5.22   3.01   1.23 ]'; %  Maedler 2006 Diabetes Fig. 1E
il_gsis_basal=[   il1(1) 10      20     200   2000 ]'; %  Maedler 2006 Diabetes Fig. 1E


il_RNA_basal=[7.385,7.015,4.964,3.651,3.241,2.092,0.574,2.872,3.241,1.559,1.559,0.410]';    % Boeni-Schnetzler 2008 J Clin Endocrinol Metab Fig. 1E   
glu_induce_fold=[0.673,0.782,0.855,0.927,0.673,0.836,2.436,1.473,2.036,3.327,3.727,4.327]'; % Boeni-Schnetzler 2008 J Clin Endocrinol Metab Fig. 1E   

glu_added=[         0,  3.0,  5.5,  11.1, 22.2, 33.3, 40]';   % Boeni-Schnetzler 2008 J Clin Endocrinol Metab Fig. 4A
glu_induce_il_fold=[0,  0.5,  1,    1.24, 1.21, 1.35, 1.77]'; % Boeni-Schnetzler 2008 J Clin Endocrinol Metab Fig. 4A
% G=3.0 hypoglycemic limit  

kd= 1300; % pg/ml, 850~1700 Dinarrello 1996 Blood

%% fit glu induced il
g = fittype('a*x^n/(b^n+x^n)', 'independent','x', 'coefficients',{'a','b','n'} );
options00=fitoptions(g);
options00.Robust='on'; 
options00.StartPoint=[1.281 2.7  2];
options00.TolFun=1e-6;
options00.maxFunEvals=800;
options00.maxIter=200;
fo_glu_induced_il= fit(glu_added(1:end), glu_induce_il_fold(1:end), g, options00);
figure; hold on; box on; 
plot(glu_added(2),glu_induce_il_fold(2),'bs')
plot(fo_glu_induced_il, glu_added([1 3 4 5 6 7],1), glu_induce_il_fold([1 3 4 5 6 7 ],1));
legend('proposed data','data','fitted curve')
xlabel('glucose (mM)')
ylabel('fold of IL-1{\beta} mRNA')
fo_glu_induced_il
%% fit basal il dependent
g = fittype('a/(b+x^2)', 'independent','x', 'coefficients',{'a','b'} ); 
% if use a/(b+x^n), the outcome is n=1.998, which makes it very difficult
% to solve steady state equations in Maple. set n=2 makes it much easier. 
options01=fitoptions(g);
options01.Robust='on'; 
options01.StartPoint=[22.31 5.818];
options01.TolFun=1e-6;
options01.maxFunEvals=800;
options01.maxIter=200;
fo_basal_il_inhibition= fit(il_RNA_basal, glu_induce_fold, g, options01);
figure; hold on; box on;
plot(fo_basal_il_inhibition,il_RNA_basal,glu_induce_fold);
xlabel('basal IL-1{\beta} mRNA')
ylabel('glucose induced IL-1{\beta} mRNA')
fo_basal_il_inhibition
%% fit auto-stimulation to F
g = fittype('(a*x^n/(b^n+x^n)+1)', 'independent','x', 'coefficients',{'a','b','n'} );
options03=fitoptions(g);
options03.Robust='on';
options03.StartPoint=[8.223 0.1481 3];
options03.TolFun=1e-8;
options03.maxFunEvals=800;
options03.maxIter=800;
options03.Lower=[8 0.05 3];
options03.Upper=[10 0.2 3.0001];
F= ( il1_il1_auto./(kd + il1_il1_auto + il1Ra_culture(1)) );
fo_il1_auto= fit( F , fold_RNA_il1_auto, g, options03);
figure; hold on;   box on;
plot(F, fold_RNA_il1_auto, '.'); plot(fo_il1_auto);
legend('data','fitted curve','Location','NorthWest'); xlabel('F'); ylabel('fold of IL-1{\beta} mRNA');
fo_il1_auto

%% fit proliferation to F
F= il1_pro_apo./(kd + il1_pro_apo + il1Ra_culture(1));
g = fittype('a*x^2+b*x+c', 'independent', 'x', 'coefficients', {'a','b','c'} );
options04 = fitoptions(g);
options04.Robust = 'on';
options04.StartPoint=[-0.04855 -0.463 0.6212];
options04.maxIter=800;
fo_log_F_pro=fit( log(F), fold_prolif, g , options04);
figure; hold on; box on;
plot(log(F), fold_prolif, 's'); plot(fo_log_F_pro);
legend('data','fitted curve','Location','NorthWest'); xlabel('log(F)'); ylabel('fold of proliferation');
fo_log_F_pro

%% fit apoptosis to F 
g = fittype('a*x^2+b*x+c', 'independent', 'x', 'coefficients', {'a','b','c'} );
options05 = fitoptions(g);
options05.Robust = 'on';
options05.StartPoint=[0.0473 0.5702 2.36];
options05.maxIter=800;
options05.maxFunEvals=1800;
fo_log_F_apo=fit( log(F), fold_apopto, g, options05);
figure; hold on; box on;
plot(log(F), fold_apopto, 's'); plot(fo_log_F_apo);
legend('data','fitted curve','Location','NorthWest'); xlabel('log(F)'); ylabel('fold of apoptosis');
fo_log_F_apo
%% save 
save fit_para_from_experiments.mat fo_*

